#!/usr/bin/env groovy
import com.urbancode.anthill3.*
import com.urbancode.anthill3.plugin.scm.*
import java.text.*


final def dateParser = new DateParser();
final def ahpTool = new AHPTool();

//------------------------------------------------------------------------------
// PARSE PROPERTIES
//------------------------------------------------------------------------------

final def stepProps = ahpTool.getStepProperties()

final def workDir = new File('.').canonicalFile
final def out = System.out


final String host       = stepProps['source/repo/repoHost']
final String username   = stepProps['source/repo/username']
final String password   = stepProps['source/repo/password']
final String accurevCmd = stepProps['source/repo/commandPath'] ?: 'accurev'

final String srcName    = stepProps['source'];
final File dir          = new File(workDir, stepProps['source/dirOffset'] ?: '.').canonicalFile // get checkout directory
final String streamName = stepProps['source/stream']

def userExcludesString  = stepProps['source/excludeUsers'] ?: ''
def fileFiltersString   = stepProps['source/fileFilters'] ?: '';

final def startRevision = stepProps['startRevision'] ?: ''
final def endRevision   = stepProps['endRevision'] ?: ''
final def startDate     = dateParser.parseDate(stepProps['startDate']) // explicit start date ?: startBuildLife.actualWorkspaceDate
final def endDate       = dateParser.parseDate(stepProps['endDate'])   // explicit end date ?: buildLife.actualWorkspaceDate
//final def startBuildLifeId = stepProps['startBuildlifeId'] ? stepProps['startBuildlifeId'] as Long : null  // change-log start status (if no explicit startDate)


//if (!startRevision && startBuildLifeId) {
//    startRevision = ahpTool.getBuildLifeProperties(startBuildLifeId)["workspace.revision.$srcName"]
//}

//if (!endRevision) {
//    endRevision = ahpTool.getBuildLifeProperties()["workspace.revision.$srcName"]
//}

//
// Execute
//
SCMChangelog changelog = new SCMChangelog();
changelog.scmCommand = accurevCmd;
changelog.host = host;
changelog.username = username;
changelog.password = password;
changelog.directory = dir;
changelog.streamName = streamName;

changelog.startRevision = startRevision
changelog.endRevision = endRevision
changelog.startDate = startDate
changelog.endDate = endDate

changelog.changeSetFilter.setUserExcludes(userExcludesString);
changelog.changeSetFilter.setFileFilters(fileFiltersString);

def xml = changelog.execute()
if (xml) {
    ahpTool.addChangeSets(xml);
    println "";
}
