#!/usr/bin/env groovy

import com.urbancode.anthill3.*
import com.urbancode.anthill3.plugin.scm.*
import java.util.Date;

final def workDir = new File('.').canonicalFile
final def out = System.out
final def env = System.getenv()

//------------------------------------------------------------------------------
// GET ALL INPUT PARAMETERS
//------------------------------------------------------------------------------
final def dateParser = new DateParser();
final def ahpTool = new AHPTool();

final def stepProps = ahpTool.getStepProperties();
final def jobProps = ahpTool.getJobProperties();
final def blProps = ahpTool.getBuildLifeProperties();

final def accurevCmd   = stepProps['source/repo/commandPath'] ?: 'accurev'
final String host      = stepProps['source/repo/repoHost']
final String username  = stepProps['source/repo/username']
final String password  = stepProps['source/repo/password']
final def srcName      = stepProps['source'];
final File dir         = new File(workDir, stepProps['source/dirOffset']).canonicalFile // get checkout directory
final String streamName    = stepProps['source/stream']
final def popLocations     = stepProps['source/popLocations']?.readLines().findAll { it }

// look for date based checkout (buildlife, then actual workspace date)
final Date date        = dateParser.parseDate(stepProps['date']) // this is from actualWorkspaceDate
final Date blDate      = dateParser.parseDate(blProps['workspace.date.$srcName']); // from checkout step

// look for revision from step (regular workspace date), then buildlife, then source config
final String revision  = stepProps['revision'];
final String blRevision = blProps["workspace.revision.$srcName"];
final String sourceRevision= stepProps['source/revision'];

//
// Perform step
//

SCMCheckout co = new SCMCheckout();
co.scmCommand = accurevCmd;
co.host = host;
co.username = username;
co.password = password;
co.directory = dir
co.streamName = streamName
co.popLocations = popLocations
co.revision = revision ?: blRevision ?: sourceRevision;
co.date = date ?: blDate
co.execute()

// set buildlife property tracking revision for use by tagging and accurate changelogs calculations
def updateBlProps = [
                "workspace.revision.$srcName":'',
                "workspace.date.$srcName":''
    ]
updateBlProps.keySet().retainAll(blProps.keySet()); // don't set stuff to blank that is currently not present

if (co.revision) {
    if (blRevision != co.revision) {
        println "Updating workspace revision on buildlife to $co.revision"
        updateBlProps["workspace.revision.$srcName"] = co.revision;
        ahpTool.setBuildLifeProperties(updateBlProps);
        println "";
    }
}
else if (co.date) {
    if (blDate != co.date) {
        println "Updating workspace date on buildlife to $co.date"
        updateBlProps["workspace.date.$srcName"] = co.date;
        ahpTool.setBuildLifeProperties(updateBlProps);
        println "";
    }
}
