package com.urbancode.anthill3.plugin.scm;

import com.urbancode.anthill3.*

import java.io.File;
import java.util.Date;

abstract public class SCMStep {

    //**************************************************************************
    // CLASS
    //**************************************************************************

    static protected final SCMHelper scmHelper = new SCMHelper();

    //**************************************************************************
    // INSTANCE
    //**************************************************************************

    def out = System.out;

    String scmCommand = "accurev";

    String host = null;
    String username = null;
    String password = null;

    File directory;
//    boolean clean = false
    String streamName;
    String revision;
    Date date;

    public void println(String msg) {
        out.println(msg);
    }

    /**
     * Method to check if login is required and authenticate with provided credentials if needed/able
     */
    protected void login() {

        final CommandHelper cmdHelper = new CommandHelper(directory);

        def infoCommand = [scmCommand, 'info']
        if (host) {
            infoCommand << '-H' << host
        }
        def infoText = new ByteArrayOutputStream();

        cmdHelper.runCommand("Check if authenticated", infoCommand) { Process proc ->
            proc.out.close() // close stdin
            def out = new PrintStream(this.out, true);
            try {
                proc.waitForProcessOutput(infoText, out) // forward stdout and stderr to autoflushing output stream
            }
            finally {
                out.flush();
            }
            println infoText;
        }

        if (infoText =~ /(?im)^principal:\s*\(not logged in\)/) {
            // run login
            if (username) {
                def loginCmd = [scmCommand, 'login'];
                if (host) {
                    loginCmd << '-H' << host
                }
                
                loginCmd << '-n' << username << (password ?: '')
                
                cmdHelper.runCommand("Authenticating with AccuRev", loginCmd);
            }
            else {
                println "No username found, continuing with anonymous access";
            }
        }
    }
}
