package com.urbancode.anthill3.plugin.scm.changelog

import java.text.SimpleDateFormat;
import java.text.DateFormat;
import java.util.TimeZone;

public class ChangeSetXMLHelper {

    //**************************************************************************
    // CLASS
    //**************************************************************************

    static private final TimeZone GMT = TimeZone.getTimeZone("GMT")
    static private final String AHP_DATE_FORMAT_STRING = "yyyy-MM-dd HH:mm:ss.S Z";

    //**************************************************************************
    // INSTANCE
    //**************************************************************************

    public def toXML(Collection<ChangeSet> changeSets) {
        final DateFormat ahpDateFormat = getAHPDateFormat();

        def xml = groovy.xml.DOMBuilder.newInstance().'change-log'{
            changeSets.each{ changeSet ->
                'change-set'(){
                    'id'(changeSet.id)
                    'user'(changeSet.user)
                    'date'(ahpDateFormat.format(changeSet.date))
                    if (changeSet.message) {
                        'comment'(changeSet.message)
                    }
                    //module('')
                    'repository-type'('mercurial')
                    'repository-id'(System.getenv()['AH_REPOSITORY_ID'])
                    'file-set'{
                        changeSet.fileSet.each{change ->
                            'file'('change-type':change.type, 'revision-number':change.revision, change.path)
                        }
                    }

                    if (changeSet.properties) {
                        'properties'{
                            changeSet.properties.each{ prop ->
                                'property'{
                                    'name'(prop.key)
                                    if (prop.value) {
                                        'value'(prop.value)
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        return xml
    }

    /**
     * Create a new AHPDate format instance based upon {@link #AHP_DATE_FORMAT_STRING}
     * @return a new {@link DateFormat}
     */
    protected DateFormat getAHPDateFormat() {
        DateFormat ahpDateFormat = new SimpleDateFormat(AHP_DATE_FORMAT_STRING);
        ahpDateFormat.timeZone = GMT;
        return ahpDateFormat;
    }
}
