#!/usr/bin/env groovy

import com.urbancode.anthill3.*
import com.urbancode.anthill3.plugin.scm.*
import java.text.*


final def dateParser = new DateParser();
final def ahpTool = new AHPTool();
final SCMHelper scmHelper = new SCMHelper();

//------------------------------------------------------------------------------
// PARSE PROPERTIES
//------------------------------------------------------------------------------

final def out = System.out
final def env = System.getenv()

final File workDir = new File('.').canonicalFile

final def stepProps = ahpTool.getStepProperties();

final def accurevCmd    = stepProps['source/repo/commandPath'] ?: 'accurev'
final String host       = stepProps['source/repo/repoHost']
final String username   = stepProps['source/repo/username']
final String password   = stepProps['source/repo/password']

final def srcName       = stepProps['source'];
final File dir          = new File(workDir, stepProps['source/dirOffset']).canonicalFile // get checkout directory
final String streamName = stepProps['source/stream']
final String userExcludesString = stepProps['source/excludeUsers'] ?: ''
final String fileFiltersString = stepProps['source/fileFilters'] ?: '';

final def startRevision = stepProps['startRevision'] ?: ''
final def endRevision   = stepProps['endRevision'] ?: ''
final def startDate     = dateParser.parseDate(stepProps['startDate'])
final def endDate       = dateParser.parseDate(stepProps['endDate'])

//
// Execute
//

SCMQuietPeriod quietPeriod = new SCMQuietPeriod();
quietPeriod.scmCommand = accurevCmd;
quietPeriod.host = host;
quietPeriod.username = username;
quietPeriod.password = password;
quietPeriod.directory = dir;
quietPeriod.streamName = streamName;

quietPeriod.startRevision = startRevision
quietPeriod.endRevision = endRevision
quietPeriod.startDate = startDate
quietPeriod.endDate = endDate

quietPeriod.changeSetFilter.setUserExcludes(userExcludesString);
quietPeriod.changeSetFilter.setFileFilters(fileFiltersString);

Date latestRevisionDate = quietPeriod.execute()

//------------------------------------------------------------------------------
// UPLOAD LATEST CHANGE DATE
//------------------------------------------------------------------------------
if (latestRevisionDate == null) {
    println('No changes detected')
}
else {
    ahpTool.setQuietPeriodLatestTime(latestRevisionDate.time)
    println('')
}
