#!/usr/bin/env groovy

import com.urbancode.anthill3.*
import com.urbancode.anthill3.plugin.scm.*

final def workDir = new File('.').canonicalFile
final def out = System.out

final def ahpTool = new AHPTool();
final def dateParser = new DateParser();

final SCMHelper scmHelper = new SCMHelper();
final def stepProps = ahpTool.getStepProperties();
final def jobProps = ahpTool.getJobProperties();
final def blProps = ahpTool.getBuildLifeProperties();

final def accurevCmd    = stepProps['source/repo/commandPath'] ?: 'accurev'
final String host       = stepProps['source/repo/repoHost']
final String username   = stepProps['source/repo/username']
final String password   = stepProps['source/repo/password']
final File dir          = new File(workDir, stepProps['source/dirOffset'] ?: '.').canonicalFile // get checkout directory
final String srcName    = stepProps['source'];
final String streamName = stepProps['source/stream']
final String newLabelName = stepProps['label']

// use buildlife revision (from checkout), then buildlife revision
final String blRevision  = blProps["workspace.revision.$srcName"]
final String srcRevision = stepProps['source/revision']

// use step-date, buildlife date (from checkout), then global workspace date
final Date date          = dateParser.parseDate(stepProps['date'])
final Date blDate        = dateParser.parseDate(blProps["workspace.date.$srcName"])
final Date wsDate        = dateParser.parseDate(jobProps['workspace.date']);

//------------------------------------------------------------------------------
// PREPARE COMMAND LINE
//------------------------------------------------------------------------------

SCMTag tag = new SCMTag();
tag.scmCommand = accurevCmd;
tag.host = host;
tag.username = username;
tag.password = password;
tag.directory = dir
tag.streamName = streamName
tag.revision = blRevision ?: srcRevision
tag.date = date ?: blDate ?: wsDate;
tag.tagName = newLabelName
tag.execute()